@@ -8,7 +8,10 @@ from core_main_app.admin import core_admin_site
 from core_elasticsearch_app.components.elasticsearch_template.models import (
     ElasticsearchTemplate,
 )
-from core_elasticsearch_app.views.admin import views as admin_views, ajax as admin_ajax
+from core_elasticsearch_app.views.admin import (
+    views as admin_views,
+    ajax as admin_ajax,
+)
 
 
 admin_urls = [
@@ -19,17 +22,23 @@ admin_urls = [
     ),
     re_path(
         r"^elasticsearch/template/add",
-        staff_member_required(admin_ajax.AddElasticsearchTemplateView.as_view()),
+        staff_member_required(
+            admin_ajax.AddElasticsearchTemplateView.as_view()
+        ),
         name="core_elasticsearch_app_templates_add",
     ),
     re_path(
         r"^elasticsearch/template/(?P<pk>[\w-]+)/delete/$",
-        staff_member_required(admin_ajax.DeleteElasticsearchTemplateView.as_view()),
+        staff_member_required(
+            admin_ajax.DeleteElasticsearchTemplateView.as_view()
+        ),
         name="core_elasticsearch_app_templates_delete",
     ),
     re_path(
         r"^elasticsearch/template/(?P<pk>[\w-]+)/edit/$",
-        staff_member_required(admin_ajax.EditElasticsearchTemplateView.as_view()),
+        staff_member_required(
+            admin_ajax.EditElasticsearchTemplateView.as_view()
+        ),
         name="core_elasticsearch_app_templates_edit",
     ),
     re_path(
