@@ -12,7 +12,9 @@ from core_elasticsearch_app.components.data.mongodb import get_value_from_path
 from core_elasticsearch_app.settings import (
     ELASTICSEARCH_CDCS_DATA_INDEX,
 )
-from core_elasticsearch_app.utils.elasticsearch_client import ElasticsearchClient
+from core_elasticsearch_app.utils.elasticsearch_client import (
+    ElasticsearchClient,
+)
 from core_elasticsearch_app.components.elasticsearch_template import (
     api as elasticsearch_template_api,
 )
@@ -63,7 +65,8 @@ def index_data(data):
         )
     except exceptions.DoesNotExist:
         logger.warning(
-            "Data with id %s will not be indexed. No template configured.", str(data.id)
+            "Data with id %s will not be indexed. No template configured.",
+            str(data.id),
         )
     except Exception as exception:
         logger.error(str(exception))
